=======
History
=======

0.1.0 (2020-09-30)
------------------

* First release but not on PyPI.
* Patch releases on Pypi after automation sorted.


0.2.0 (2020-09-30)
------------------

* Support for list returns - eg ``ServiceProviderServicePackGetListResponse``
